Documentation
¶
Index ¶
- Constants
- Variables
- func Active(v bool) predicate.User
- func ActiveEQ(v bool) predicate.User
- func ActiveNEQ(v bool) predicate.User
- func And(predicates ...predicate.User) predicate.User
- func AvatarURL(v string) predicate.User
- func AvatarURLContains(v string) predicate.User
- func AvatarURLContainsFold(v string) predicate.User
- func AvatarURLEQ(v string) predicate.User
- func AvatarURLEqualFold(v string) predicate.User
- func AvatarURLGT(v string) predicate.User
- func AvatarURLGTE(v string) predicate.User
- func AvatarURLHasPrefix(v string) predicate.User
- func AvatarURLHasSuffix(v string) predicate.User
- func AvatarURLIn(vs ...string) predicate.User
- func AvatarURLIsNil() predicate.User
- func AvatarURLLT(v string) predicate.User
- func AvatarURLLTE(v string) predicate.User
- func AvatarURLNEQ(v string) predicate.User
- func AvatarURLNotIn(vs ...string) predicate.User
- func AvatarURLNotNil() predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func ID(id string) predicate.User
- func IDContainsFold(id string) predicate.User
- func IDEQ(id string) predicate.User
- func IDEqualFold(id string) predicate.User
- func IDGT(id string) predicate.User
- func IDGTE(id string) predicate.User
- func IDIn(ids ...string) predicate.User
- func IDLT(id string) predicate.User
- func IDLTE(id string) predicate.User
- func IDNEQ(id string) predicate.User
- func IDNotIn(ids ...string) predicate.User
- func LastLogin(v time.Time) predicate.User
- func LastLoginEQ(v time.Time) predicate.User
- func LastLoginGT(v time.Time) predicate.User
- func LastLoginGTE(v time.Time) predicate.User
- func LastLoginIn(vs ...time.Time) predicate.User
- func LastLoginIsNil() predicate.User
- func LastLoginLT(v time.Time) predicate.User
- func LastLoginLTE(v time.Time) predicate.User
- func LastLoginNEQ(v time.Time) predicate.User
- func LastLoginNotIn(vs ...time.Time) predicate.User
- func LastLoginNotNil() predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func PasswordHash(v string) predicate.User
- func PasswordHashContains(v string) predicate.User
- func PasswordHashContainsFold(v string) predicate.User
- func PasswordHashEQ(v string) predicate.User
- func PasswordHashEqualFold(v string) predicate.User
- func PasswordHashGT(v string) predicate.User
- func PasswordHashGTE(v string) predicate.User
- func PasswordHashHasPrefix(v string) predicate.User
- func PasswordHashHasSuffix(v string) predicate.User
- func PasswordHashIn(vs ...string) predicate.User
- func PasswordHashLT(v string) predicate.User
- func PasswordHashLTE(v string) predicate.User
- func PasswordHashNEQ(v string) predicate.User
- func PasswordHashNotIn(vs ...string) predicate.User
- func Role(v string) predicate.User
- func RoleContains(v string) predicate.User
- func RoleContainsFold(v string) predicate.User
- func RoleEQ(v string) predicate.User
- func RoleEqualFold(v string) predicate.User
- func RoleGT(v string) predicate.User
- func RoleGTE(v string) predicate.User
- func RoleHasPrefix(v string) predicate.User
- func RoleHasSuffix(v string) predicate.User
- func RoleIn(vs ...string) predicate.User
- func RoleLT(v string) predicate.User
- func RoleLTE(v string) predicate.User
- func RoleNEQ(v string) predicate.User
- func RoleNotIn(vs ...string) predicate.User
- func UpdatedAt(v time.Time) predicate.User
- func UpdatedAtEQ(v time.Time) predicate.User
- func UpdatedAtGT(v time.Time) predicate.User
- func UpdatedAtGTE(v time.Time) predicate.User
- func UpdatedAtIn(vs ...time.Time) predicate.User
- func UpdatedAtLT(v time.Time) predicate.User
- func UpdatedAtLTE(v time.Time) predicate.User
- func UpdatedAtNEQ(v time.Time) predicate.User
- func UpdatedAtNotIn(vs ...time.Time) predicate.User
- func Username(v string) predicate.User
- func UsernameContains(v string) predicate.User
- func UsernameContainsFold(v string) predicate.User
- func UsernameEQ(v string) predicate.User
- func UsernameEqualFold(v string) predicate.User
- func UsernameGT(v string) predicate.User
- func UsernameGTE(v string) predicate.User
- func UsernameHasPrefix(v string) predicate.User
- func UsernameHasSuffix(v string) predicate.User
- func UsernameIn(vs ...string) predicate.User
- func UsernameLT(v string) predicate.User
- func UsernameLTE(v string) predicate.User
- func UsernameNEQ(v string) predicate.User
- func UsernameNotIn(vs ...string) predicate.User
- func ValidColumn(column string) bool
- type OrderOption
- func ByActive(opts ...sql.OrderTermOption) OrderOption
- func ByAvatarURL(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLastLogin(opts ...sql.OrderTermOption) OrderOption
- func ByPasswordHash(opts ...sql.OrderTermOption) OrderOption
- func ByRole(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUsername(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldUsername holds the string denoting the username field in the database. FieldUsername = "username" // FieldPasswordHash holds the string denoting the password_hash field in the database. FieldPasswordHash = "password_hash" // FieldRole holds the string denoting the role field in the database. FieldRole = "role" // FieldActive holds the string denoting the active field in the database. FieldActive = "active" // FieldAvatarURL holds the string denoting the avatar_url field in the database. FieldAvatarURL = "avatar_url" // FieldLastLogin holds the string denoting the last_login field in the database. FieldLastLogin = "last_login" // Table holds the table name of the user in the database. Table = "users" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error // UsernameValidator is a validator for the "username" field. It is called by the builders before save. UsernameValidator func(string) error // PasswordHashValidator is a validator for the "password_hash" field. It is called by the builders before save. PasswordHashValidator func(string) error // DefaultRole holds the default value on creation for the "role" field. DefaultRole string // DefaultActive holds the default value on creation for the "active" field. DefaultActive bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() string // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(string) error )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldEmail, FieldUsername, FieldPasswordHash, FieldRole, FieldActive, FieldAvatarURL, FieldLastLogin, }
Columns holds all SQL columns for user fields.
Functions ¶
func Active ¶
Active applies equality check predicate on the "active" field. It's identical to ActiveEQ.
func AvatarURL ¶
AvatarURL applies equality check predicate on the "avatar_url" field. It's identical to AvatarURLEQ.
func AvatarURLContains ¶
AvatarURLContains applies the Contains predicate on the "avatar_url" field.
func AvatarURLContainsFold ¶
AvatarURLContainsFold applies the ContainsFold predicate on the "avatar_url" field.
func AvatarURLEQ ¶
AvatarURLEQ applies the EQ predicate on the "avatar_url" field.
func AvatarURLEqualFold ¶
AvatarURLEqualFold applies the EqualFold predicate on the "avatar_url" field.
func AvatarURLGT ¶
AvatarURLGT applies the GT predicate on the "avatar_url" field.
func AvatarURLGTE ¶
AvatarURLGTE applies the GTE predicate on the "avatar_url" field.
func AvatarURLHasPrefix ¶
AvatarURLHasPrefix applies the HasPrefix predicate on the "avatar_url" field.
func AvatarURLHasSuffix ¶
AvatarURLHasSuffix applies the HasSuffix predicate on the "avatar_url" field.
func AvatarURLIn ¶
AvatarURLIn applies the In predicate on the "avatar_url" field.
func AvatarURLIsNil ¶
AvatarURLIsNil applies the IsNil predicate on the "avatar_url" field.
func AvatarURLLT ¶
AvatarURLLT applies the LT predicate on the "avatar_url" field.
func AvatarURLLTE ¶
AvatarURLLTE applies the LTE predicate on the "avatar_url" field.
func AvatarURLNEQ ¶
AvatarURLNEQ applies the NEQ predicate on the "avatar_url" field.
func AvatarURLNotIn ¶
AvatarURLNotIn applies the NotIn predicate on the "avatar_url" field.
func AvatarURLNotNil ¶
AvatarURLNotNil applies the NotNil predicate on the "avatar_url" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func LastLogin ¶
LastLogin applies equality check predicate on the "last_login" field. It's identical to LastLoginEQ.
func LastLoginEQ ¶
LastLoginEQ applies the EQ predicate on the "last_login" field.
func LastLoginGT ¶
LastLoginGT applies the GT predicate on the "last_login" field.
func LastLoginGTE ¶
LastLoginGTE applies the GTE predicate on the "last_login" field.
func LastLoginIn ¶
LastLoginIn applies the In predicate on the "last_login" field.
func LastLoginIsNil ¶
LastLoginIsNil applies the IsNil predicate on the "last_login" field.
func LastLoginLT ¶
LastLoginLT applies the LT predicate on the "last_login" field.
func LastLoginLTE ¶
LastLoginLTE applies the LTE predicate on the "last_login" field.
func LastLoginNEQ ¶
LastLoginNEQ applies the NEQ predicate on the "last_login" field.
func LastLoginNotIn ¶
LastLoginNotIn applies the NotIn predicate on the "last_login" field.
func LastLoginNotNil ¶
LastLoginNotNil applies the NotNil predicate on the "last_login" field.
func PasswordHash ¶
PasswordHash applies equality check predicate on the "password_hash" field. It's identical to PasswordHashEQ.
func PasswordHashContains ¶
PasswordHashContains applies the Contains predicate on the "password_hash" field.
func PasswordHashContainsFold ¶
PasswordHashContainsFold applies the ContainsFold predicate on the "password_hash" field.
func PasswordHashEQ ¶
PasswordHashEQ applies the EQ predicate on the "password_hash" field.
func PasswordHashEqualFold ¶
PasswordHashEqualFold applies the EqualFold predicate on the "password_hash" field.
func PasswordHashGT ¶
PasswordHashGT applies the GT predicate on the "password_hash" field.
func PasswordHashGTE ¶
PasswordHashGTE applies the GTE predicate on the "password_hash" field.
func PasswordHashHasPrefix ¶
PasswordHashHasPrefix applies the HasPrefix predicate on the "password_hash" field.
func PasswordHashHasSuffix ¶
PasswordHashHasSuffix applies the HasSuffix predicate on the "password_hash" field.
func PasswordHashIn ¶
PasswordHashIn applies the In predicate on the "password_hash" field.
func PasswordHashLT ¶
PasswordHashLT applies the LT predicate on the "password_hash" field.
func PasswordHashLTE ¶
PasswordHashLTE applies the LTE predicate on the "password_hash" field.
func PasswordHashNEQ ¶
PasswordHashNEQ applies the NEQ predicate on the "password_hash" field.
func PasswordHashNotIn ¶
PasswordHashNotIn applies the NotIn predicate on the "password_hash" field.
func RoleContains ¶
RoleContains applies the Contains predicate on the "role" field.
func RoleContainsFold ¶
RoleContainsFold applies the ContainsFold predicate on the "role" field.
func RoleEqualFold ¶
RoleEqualFold applies the EqualFold predicate on the "role" field.
func RoleHasPrefix ¶
RoleHasPrefix applies the HasPrefix predicate on the "role" field.
func RoleHasSuffix ¶
RoleHasSuffix applies the HasSuffix predicate on the "role" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func Username ¶
Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.
func UsernameContains ¶
UsernameContains applies the Contains predicate on the "username" field.
func UsernameContainsFold ¶
UsernameContainsFold applies the ContainsFold predicate on the "username" field.
func UsernameEQ ¶
UsernameEQ applies the EQ predicate on the "username" field.
func UsernameEqualFold ¶
UsernameEqualFold applies the EqualFold predicate on the "username" field.
func UsernameGT ¶
UsernameGT applies the GT predicate on the "username" field.
func UsernameGTE ¶
UsernameGTE applies the GTE predicate on the "username" field.
func UsernameHasPrefix ¶
UsernameHasPrefix applies the HasPrefix predicate on the "username" field.
func UsernameHasSuffix ¶
UsernameHasSuffix applies the HasSuffix predicate on the "username" field.
func UsernameIn ¶
UsernameIn applies the In predicate on the "username" field.
func UsernameLT ¶
UsernameLT applies the LT predicate on the "username" field.
func UsernameLTE ¶
UsernameLTE applies the LTE predicate on the "username" field.
func UsernameNEQ ¶
UsernameNEQ applies the NEQ predicate on the "username" field.
func UsernameNotIn ¶
UsernameNotIn applies the NotIn predicate on the "username" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByActive ¶
func ByActive(opts ...sql.OrderTermOption) OrderOption
ByActive orders the results by the active field.
func ByAvatarURL ¶
func ByAvatarURL(opts ...sql.OrderTermOption) OrderOption
ByAvatarURL orders the results by the avatar_url field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLastLogin ¶
func ByLastLogin(opts ...sql.OrderTermOption) OrderOption
ByLastLogin orders the results by the last_login field.
func ByPasswordHash ¶
func ByPasswordHash(opts ...sql.OrderTermOption) OrderOption
ByPasswordHash orders the results by the password_hash field.
func ByRole ¶
func ByRole(opts ...sql.OrderTermOption) OrderOption
ByRole orders the results by the role field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUsername ¶
func ByUsername(opts ...sql.OrderTermOption) OrderOption
ByUsername orders the results by the username field.